summaryrefslogtreecommitdiffstats
path: root/chrome/browser/find_bar_controller.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/find_bar_controller.h
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/find_bar_controller.h')
-rw-r--r--chrome/browser/find_bar_controller.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/find_bar_controller.h b/chrome/browser/find_bar_controller.h
index 5cdabda..fc286ef 100644
--- a/chrome/browser/find_bar_controller.h
+++ b/chrome/browser/find_bar_controller.h
@@ -10,7 +10,7 @@
#include "chrome/common/notification_observer.h"
class FindBar;
-class WebContents;
+class TabContents;
class FindBarController : public NotificationObserver {
public:
@@ -25,12 +25,12 @@ class FindBarController : public NotificationObserver {
// Ends the current session.
void EndFindSession();
- // Accessor for the attached WebContents.
- WebContents* web_contents() const { return web_contents_; }
+ // Accessor for the attached TabContents.
+ TabContents* tab_contents() const { return tab_contents_; }
- // Changes the WebContents that this FindBar is attached to. This occurs when
+ // Changes the TabContents that this FindBar is attached to. This occurs when
// the user switches tabs in the Browser window. |contents| can be NULL.
- void ChangeWebContents(WebContents* contents);
+ void ChangeTabContents(TabContents* contents);
// Overridden from NotificationObserver:
virtual void Observe(NotificationType type,
@@ -42,8 +42,8 @@ class FindBarController : public NotificationObserver {
private:
scoped_ptr<FindBar> find_bar_;
- // The WebContents we are currently associated with. Can be NULL.
- WebContents* web_contents_;
+ // The TabContents we are currently associated with. Can be NULL.
+ TabContents* tab_contents_;
DISALLOW_COPY_AND_ASSIGN(FindBarController);
};